@@ -14,6 +14,7 @@ DEFAULT_SQL_DIR = "sql/"
 DEFAULT_DAGS_FILE = "dags.yaml"
 QUERY_FILE = "query.sql"
 QUERY_PART_FILE = "part1.sql"
+SCRIPT_FILE = "script.sql"
 DEFAULT_DAGS_DIR = "dags"
 TELEMETRY_AIRFLOW_GITHUB = "https://github.com/mozilla/telemetry-airflow.git"
 
@@ -33,9 +34,16 @@ parser.add_argument(
 parser.add_argument(
     "--output_dir",
     "--output-dir",
-    default=DEFAULT_DAGS_DIR,
     help="Generated DAGs are written to this output directory.",
+    default=DEFAULT_DAGS_DIR,
 )
+parser.add_argument(
+    "--dag_id",
+    "--dag_id",
+    help="The DAG to generate. Generates all DAGs by default",
+    default=None,
+)
+
 standard_args.add_log_level(parser)
 
 
@@ -57,6 +65,9 @@ def get_dags(sql_dir, dags_config):
                     task = Task.of_multipart_query(
                         query_file, dag_collection=dag_collection
                     )
+                elif SCRIPT_FILE in files:
+                    query_file = os.path.join(root, SCRIPT_FILE)
+                    task = Task.of_script(query_file, dag_collection=dag_collection)
                 else:
                     continue
             except FileNotFoundError:
@@ -96,7 +107,7 @@ def main():
     dags_output_dir = Path(args.output_dir)
 
     dags = get_dags(args.sql_dir, args.dags_config)
-    dags.to_airflow_dags(dags_output_dir)
+    dags.to_airflow_dags(dags_output_dir, args.dag_id)
 
 
 if __name__ == "__main__":
